@@ -1,22 +1,31 @@
-/*
- * IPv4/IPv6 Subnet Calculator
- * Copyright (C) 2009-2024 by Thomas Dreibholz
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Contact: thomas.dreibholz@gmail.com
- */
+// ==========================================================================
+//             ____        _     _   _      _    ____      _
+//            / ___| _   _| |__ | \ | | ___| |_ / ___|__ _| | ___
+//            \___ \| | | | '_ \|  \| |/ _ \ __| |   / _` | |/ __|
+//             ___) | |_| | |_) | |\  |  __/ |_| |__| (_| | | (__
+//            |____/ \__,_|_.__/|_| \_|\___|\__|\____\__,_|_|\___|
+//
+//                    ---  IPv4/IPv6 Subnet Calculator  ---
+//                   https://www.nntb.no/~dreibh/subnetcalc/
+// ==========================================================================
+//
+// SubNetCalc - IPv4/IPv6 Subnet Calculator
+// Copyright (C) 2024-2025 by Thomas Dreibholz
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
+// Contact: thomas.dreibholz@gmail.com
 
 #ifndef TOOLS_H
 #define TOOLS_H
@@ -25,6 +34,7 @@
 #include <config.h>
 #endif
 
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -83,5 +93,6 @@ void printAddress(std::ostream&          os,
                   const struct sockaddr* address,
                   const bool             port      = true,
                   const bool             hideScope = false);
+std::string format(const char* fmt, ...);
 
 #endif
